@@ -43,13 +43,11 @@ import java.awt.Graphics;
 import java.awt.Graphics2D;
 import java.awt.Image;
 import java.awt.Insets;
-import java.awt.Rectangle;
 import java.io.IOException;
 import java.net.URL;
 import javax.imageio.ImageIO;
 import javax.swing.JDialog;
 import net.sourceforge.jnlp.cache.ResourceTracker;
-import net.sourceforge.jnlp.runtime.JNLPRuntime;
 import net.sourceforge.jnlp.splashscreen.SplashPanel;
 import net.sourceforge.jnlp.splashscreen.SplashUtils;
 import net.sourceforge.jnlp.splashscreen.parts.InformationElement;
@@ -64,11 +62,12 @@ public class JNLPSplashScreen extends JDialog {
 
     URL splashImageUrl;
     Image splashImage;
-    private final JNLPFile file;
+    private JNLPFile file;
     public static final  int DEF_WIDTH=635;
     public static final  int DEF_HEIGHT=480;
     private SplashPanel componetSplash;
     private boolean splashImageLoaded=false;
+    private SplashPanel splash;
 
     public JNLPSplashScreen(ResourceTracker resourceTracker, final JNLPFile file) {
 
@@ -105,7 +104,7 @@ public class JNLPSplashScreen extends JDialog {
 
             if (splashImage == null) {
                 this.setLayout(new BorderLayout());
-                SplashPanel splash = SplashUtils.getSplashScreen(DEF_WIDTH, DEF_HEIGHT);
+                splash = SplashUtils.getSplashScreen(DEF_WIDTH, DEF_HEIGHT);
                 if (splash != null) {
                     splash.startAnimation();
                     splash.setInformationElement(InformationElement.createFromJNLP(file));
@@ -119,6 +118,15 @@ public class JNLPSplashScreen extends JDialog {
         }
     }
 
+    public void setFile(JNLPFile file) {
+        this.file = file;
+        if (splash != null) {
+            splash.setInformationElement(InformationElement.createFromJNLP(file));
+        }
+    }
+    
+    
+
     public boolean isSplashImageLoaded() {
         return splashImageLoaded;
     }
@@ -165,4 +173,14 @@ public class JNLPSplashScreen extends JDialog {
     public void stopAnimation() {
         if (isCustomSplashscreen()) componetSplash.stopAnimation();
     }
+
+    public void setErrorSplash(Throwable ex) {
+        if (splash != null){
+            this.remove(splash.getSplashComponent());
+            splash = SplashUtils.getErrorSplashScreen(splash.getSplashWidth(), splash.getSplashHeight(), ex);
+            this.add(splash.getSplashComponent());
+            this.componetSplash = splash;
+            this.validate();
+    }
+    }
 }
