@@ -30,6 +30,8 @@ import java.io.Reader;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.nio.channels.FileLock;
+import java.text.SimpleDateFormat;
+import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.Properties;
@@ -55,6 +57,8 @@ public final class DeploymentConfiguration {
     public static final String APPLET_TRUST_SETTINGS = ".appletTrustSettings";
 
     public static final String DEPLOYMENT_COMMENT = "Netx deployment configuration";
+    public String userComments;
+    public String systemComments;
 
     public static final int JNLP_ASSOCIATION_NEVER = 0;
     public static final int JNLP_ASSOCIATION_NEW_ONLY = 1;
@@ -174,6 +178,8 @@ public final class DeploymentConfiguration {
     public static final String KEY_ENABLE_LOGGING = "deployment.log"; //same as verbose or ICEDTEAPLUGIN_DEBUG=true
     public static final String KEY_ENABLE_LOGGING_HEADERS = "deployment.log.headers"; //will add header OutputContorll.getHeader To all messages
     public static final String KEY_ENABLE_LOGGING_TOFILE = "deployment.log.file";
+    public static final String KEY_ENABLE_APPLICATION_LOGGING_TOFILE ="deployment.log.file.clientapp"; //also client app will log to its separate file
+    public static final String KEY_ENABLE_LEGACY_LOGBASEDFILELOG = "deployment.log.file.legacylog";
     public static final String KEY_ENABLE_LOGGING_TOSTREAMS = "deployment.log.stdstreams";
     public static final String KEY_ENABLE_LOGGING_TOSYSTEMLOG = "deployment.log.system";
     
@@ -231,7 +237,7 @@ public final class DeploymentConfiguration {
     public void resetToDefaults() {
         currentConfiguration = Defaults.getDefaults();
     }
-    
+
 
     public enum ConfigType {
         System, User
@@ -308,6 +314,7 @@ public final class DeploymentConfiguration {
                 /* Second, read the System level deployment.properties file */
                 systemProperties = loadProperties(ConfigType.System, systemPropertiesFile,
                         systemPropertiesMandatory);
+                systemComments=loadComments(systemPropertiesFile);
             }
             if (systemProperties != null) {
                 mergeMaps(initialProperties, systemProperties);
@@ -326,6 +333,7 @@ public final class DeploymentConfiguration {
          */
         userPropertiesFile = userFile;
         Map<String, Setting<String>> userProperties = loadProperties(ConfigType.User, userPropertiesFile, false);
+        userComments=loadComments(userPropertiesFile);
         if (userProperties != null) {
             mergeMaps(initialProperties, userProperties);
         }
@@ -631,7 +639,11 @@ public final class DeploymentConfiguration {
 
         FileUtils.createParentDir(userPropertiesFile);
         try (OutputStream out = new BufferedOutputStream(new FileOutputStream(userPropertiesFile))) {
-            toSave.store(out, DEPLOYMENT_COMMENT);
+            String comments = DEPLOYMENT_COMMENT;
+            if (userComments.length() > 0) {
+                comments = comments + System.lineSeparator() + userComments;
+            }
+            toSave.store(out, comments); ;
         }
     }
 
@@ -856,4 +868,43 @@ public final class DeploymentConfiguration {
             return 1;
         }
     }
+    
+    //standard date.toString format
+    public static final SimpleDateFormat pattern = new SimpleDateFormat("EEE MMM dd HH:mm:ss zzz yyyy");
+    
+    private static String loadComments(File path) {
+        StringBuilder r = new StringBuilder();
+        try (BufferedReader br = new BufferedReader(new FileReader(path))) {
+            while (true) {
+                String s = br.readLine();
+                if (s == null) {
+                    break;
+                }
+                s = s.trim();
+                if (s.startsWith("#")) {
+                    String decommented = s.substring(1);
+                    if (decommented.isEmpty()){
+                        continue;
+                    }
+                    if (decommented.equals(DEPLOYMENT_COMMENT)){
+                        continue;
+                    }
+                    //there is always also date
+                    Date dd = null;
+                    try {
+                        dd = pattern.parse(decommented);
+                    } catch (Exception ex) {
+                        //we really dont care, failure is our decision point
+                    }
+                    if (dd == null){
+                        r.append(decommented).append("\n");
+                    }
+                }
+            }
+        } catch (Exception ex) {
+            OutputController.getLogger().log(ex);
+        }
+        
+        return r.toString().trim();
+    }
 }
