@@ -25,6 +25,7 @@ import java.awt.Dimension;
 import java.awt.FlowLayout;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
+import java.awt.GridLayout;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
@@ -57,17 +58,19 @@ import net.sourceforge.jnlp.runtime.Translator;
 @SuppressWarnings("serial")
 public class NetworkSettingsPanel extends JPanel implements ActionListener {
 
-    private DeploymentConfiguration config;
+    private final DeploymentConfiguration config;
 
     private JPanel description;
-    private ArrayList<JPanel> proxyPanels = new ArrayList<JPanel>(); // The stuff with editable fields
+    private final ArrayList<JPanel> proxyPanels = new ArrayList<>(); // The stuff with editable fields
 
     /** List of properties used by this panel */
-    public static String[] properties = { "deployment.proxy.type",
-            "deployment.proxy.http.host",
-            "deployment.proxy.http.port",
-            "deployment.proxy.bypass.local",
-            "deployment.proxy.auto.config.url", };
+    public static String[] properties = {
+        DeploymentConfiguration.KEY_PROXY_TYPE,
+        DeploymentConfiguration.KEY_PROXY_HTTP_HOST,
+        DeploymentConfiguration.KEY_PROXY_HTTP_PORT,
+        DeploymentConfiguration.KEY_PROXY_BYPASS_LOCAL,
+        DeploymentConfiguration.KEY_PROXY_AUTO_CONFIG_URL
+    };
 
     /**
      * Creates a new instance of the network settings panel.
@@ -108,8 +111,8 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
             this.description.add(description[i], String.valueOf(i - 1));
 
         // Settings for selecting Proxy Server
-        JPanel proxyServerPanel = new JPanel(new BorderLayout());
-        JPanel proxyLocationPanel = new JPanel(new FlowLayout(FlowLayout.LEADING));
+        JPanel proxyServerPanel = new JPanel(new GridLayout(0, 1));
+        JPanel proxyLocationPanel = new JPanel(new GridBagLayout());
         JPanel proxyBypassPanel = new JPanel(new FlowLayout(FlowLayout.LEADING));
 
         JLabel addressLabel = new JLabel(Translator.R("NSAddress") + ":");
@@ -140,17 +143,24 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
                 config.setProperty(properties[3], String.valueOf(e.getStateChange() == ItemEvent.SELECTED));
             }
         });
-        proxyLocationPanel.add(Box.createRigidArea(new Dimension(13, 0)));
-        proxyLocationPanel.add(addressLabel);
-        proxyLocationPanel.add(addressField);
-        proxyLocationPanel.add(portLabel);
-        proxyLocationPanel.add(portField);
-        proxyLocationPanel.add(advancedProxyButton);
-        proxyBypassPanel.add(Box.createRigidArea(new Dimension(10, 0)));
+        c.gridy = 0;
+        c.gridx = GridBagConstraints.RELATIVE;
+        c.weightx = 0;
+        proxyLocationPanel.add(Box.createHorizontalStrut(20), c);
+        proxyLocationPanel.add(addressLabel, c);
+        c.weightx = 1;
+        proxyLocationPanel.add(addressField, c);
+        c.weightx = 0;
+        proxyLocationPanel.add(portLabel, c);
+        c.weightx = 1;
+        proxyLocationPanel.add(portField, c);
+        c.weightx = 0;
+        proxyLocationPanel.add(advancedProxyButton, c);
+        proxyBypassPanel.add(Box.createHorizontalStrut(5));
         proxyBypassPanel.add(bypassCheckBox);
 
-        proxyServerPanel.add(proxyLocationPanel, BorderLayout.CENTER);
-        proxyServerPanel.add(proxyBypassPanel, BorderLayout.SOUTH);
+        proxyServerPanel.add(proxyLocationPanel);
+        proxyServerPanel.add(proxyBypassPanel);
 
         JRadioButton directConnection = new JRadioButton(Translator.R("NSDirectConnection"), config.getProperty(properties[0]).equals("0"));
         directConnection.setActionCommand("0");
@@ -175,15 +185,20 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
         modeSelect.add(directConnection);
 
         // Settings for Automatic Proxy Configuration Script
-        JPanel proxyAutoPanel = new JPanel(new FlowLayout(FlowLayout.LEADING));
+        JPanel proxyAutoPanel = new JPanel(new GridBagLayout());
         JLabel locationLabel = new JLabel(Translator.R("NSScriptLocation") + ":");
         final JTextField locationField = new JTextField(config.getProperty(properties[4]), 20);
         locationField.getDocument().addDocumentListener(new DocumentAdapter(config, properties[4]));
 
-        proxyAutoPanel.add(Box.createRigidArea(new Dimension(13, 0)));
-        proxyAutoPanel.add(locationLabel);
-        proxyAutoPanel.add(locationField);
+        c.gridx = 0;
+        proxyAutoPanel.add(Box.createHorizontalStrut(20), c);
+        c.gridx = GridBagConstraints.RELATIVE;
+        proxyAutoPanel.add(locationLabel, c);
+        c.weightx = 1;
+        proxyAutoPanel.add(locationField, c);
 
+        c.weighty = 0;
+        c.gridx = 0;
         c.gridy = 0;
         settingPanel.add(networkDesc, c);
         c.gridy = 1;
@@ -246,18 +261,23 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
      */
     private void setState() {
         ((CardLayout) this.description.getLayout()).show(this.description, config.getProperty(properties[0]));
-        if (config.getProperty(properties[0]).equals("0")) {
-            for (JPanel panel : proxyPanels)
-                enablePanel(panel, false);
-        } else if (config.getProperty(properties[0]).equals("1")) {
-            enablePanel(proxyPanels.get(1), false);
-            enablePanel(proxyPanels.get(0), true);
-        } else if (config.getProperty(properties[0]).equals("2")) {
-            enablePanel(proxyPanels.get(0), false);
-            enablePanel(proxyPanels.get(1), true);
-        } else if (config.getProperty(properties[0]).equals("3")) {
-            for (JPanel panel : proxyPanels)
-                enablePanel(panel, false);
+        switch (config.getProperty(properties[0])) {
+            case "0":
+                for (JPanel panel : proxyPanels)
+                    enablePanel(panel, false);
+                break;
+            case "1":
+                enablePanel(proxyPanels.get(1), false);
+                enablePanel(proxyPanels.get(0), true);
+                break;
+            case "2":
+                enablePanel(proxyPanels.get(0), false);
+                enablePanel(proxyPanels.get(1), true);
+                break;
+            case "3":
+                for (JPanel panel : proxyPanels)
+                    enablePanel(panel, false);
+                break;
         }
     }
     
@@ -267,6 +287,7 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
      */
     public static PlainDocument getPortNumberDocument(){
         return new PlainDocument(){
+            @Override
             public void insertString(int offs, String str, AttributeSet a) throws BadLocationException {
                 if (str != null) {
                     try {
@@ -281,7 +302,6 @@ public class NetworkSettingsPanel extends JPanel implements ActionListener {
                                 , JOptionPane.WARNING_MESSAGE);
                     }
                 }
-                return;
             }
         };
     }
