@@ -67,6 +67,7 @@ import net.sourceforge.jnlp.security.KeyStores;
 import net.sourceforge.jnlp.security.SecurityDialogMessageHandler;
 import net.sourceforge.jnlp.security.SecurityUtil;
 import net.sourceforge.jnlp.services.XServiceManagerStub;
+import net.sourceforge.jnlp.util.BasicExceptionDialog;
 import net.sourceforge.jnlp.util.FileUtils;
 import net.sourceforge.jnlp.util.logging.JavaConsole;
 import net.sourceforge.jnlp.util.logging.LogConfig;
@@ -151,6 +152,9 @@ public class JNLPRuntime {
 
     /** all security dialogs will be consumed and pretented as being verified by user and allowed.*/
     private static boolean trustAll=false;
+    
+    /** flag keeping rest of jnlpruntime live that javaws was lunched as -html */
+    private static boolean html=false;
 
     /** all security dialogs will be consumed and we will pretend the Sandbox option was chosen */
     private static boolean trustNone = false;
@@ -830,7 +834,15 @@ public class JNLPRuntime {
         }
     }
 
-    static void setTrustAll(boolean b) {
+    public static void setHtml(boolean html) {
+        JNLPRuntime.html = html;
+    }
+
+    public static boolean isHtml() {
+        return html;
+    }
+
+    public static void setTrustAll(boolean b) {
         trustAll=b;
     }
 
@@ -838,7 +850,7 @@ public class JNLPRuntime {
         return trustAll;
     }
 
-    static void setTrustNone(final boolean b) {
+    public static void setTrustNone(final boolean b) {
         trustNone = b;
     }
 
@@ -869,7 +881,14 @@ public class JNLPRuntime {
     }
 
     public static void exit(int i) {
-        OutputController.getLogger().close();
+        try {
+            OutputController.getLogger().close();
+            while (BasicExceptionDialog.areShown()){
+                Thread.sleep(100);
+            }
+        } catch (Exception ex) {
+            //to late
+        }
         System.exit(i);
     }
 
