@@ -59,6 +59,8 @@ import java.io.IOException;
 import java.lang.ref.WeakReference;
 import java.lang.reflect.InvocationTargetException;
 import java.net.MalformedURLException;
+import java.net.URISyntaxException;
+import java.net.URI;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -333,9 +335,18 @@ public class PolicyEditor extends JPanel {
          openDefaultButtonAction = new ActionListener() {
             @Override
             public void actionPerformed(final ActionEvent e) {
-                if (!promptOnSaveChangesMade(true)) return;
-                    PolicyEditor.this.setFile(PathsAndFiles.JAVA_POLICY.getFullPath());
-                    openAndParsePolicyFile();
+                if (!promptOnSaveChangesMade(true)) {
+                    return;
+                }
+                try {
+                    PolicyEditor.this.setFile(getDefaultPolicyFilePath());
+                    PolicyEditor.this.getFile().createNewFile();
+                } catch (final IOException ex) {
+                    OutputController.getLogger().log(ex);
+                } catch (final URISyntaxException ex) {
+                    OutputController.getLogger().log(ex);
+                }
+                openAndParsePolicyFile();
             }
         };
 
@@ -470,6 +481,10 @@ public class PolicyEditor extends JPanel {
 
         setupLayout();
     }
+
+    private static String getDefaultPolicyFilePath() throws URISyntaxException {
+        return new File(new URI(PathsAndFiles.JAVA_POLICY.getFullPath())).getAbsolutePath();
+    }
     
     private boolean getModality() {
         boolean modal = false;
@@ -1628,13 +1643,7 @@ public class PolicyEditor extends JPanel {
         SwingUtilities.invokeLater(new Runnable() {
             @Override
             public void run() {
-                String filepath = optionParser.getParam(OptionsDefinitions.OPTIONS.FILE);
-                if (optionParser.getMainArgs().size() == 0) {
-                    filepath = null;
-                } else if (filepath.isEmpty()) {
-                    // maybe the user just forgot the -file flag, so try to open anyway
-                    filepath = optionParser.getMainArg();
-                }
+                final String filepath = getFilePathArgument(optionParser);
                 final PolicyEditorWindow frame = getPolicyEditorFrame(filepath);
                 frame.asWindow().setVisible(true);
                 final List<String> codebases = optionParser.getParams(OptionsDefinitions.OPTIONS.CODEBASE);
@@ -1645,6 +1654,42 @@ public class PolicyEditor extends JPanel {
         });
     }
 
+    private static String getFilePathArgument(OptionParser optionParser) {
+        final boolean openDefaultFile = optionParser.hasOption(OptionsDefinitions.OPTIONS.DEFAULTFILE);
+        final boolean hasFileArgument = optionParser.hasOption(OptionsDefinitions.OPTIONS.FILE);
+        final boolean hasMainArgument = optionParser.mainArgExists();
+        if ((hasFileArgument && openDefaultFile) || (hasMainArgument && openDefaultFile)) {
+            throw new IllegalArgumentException(R("PEDefaultFileFilePathSpecifiedError"));
+        } else if (hasFileArgument && hasMainArgument) {
+            throw new IllegalArgumentException(R("PEMainArgAndFileSwitchSpecifiedError"));
+        }
+
+        String filepath = null;
+        if (hasFileArgument) {
+            filepath = cleanFilePathArgument(optionParser.getParam(OptionsDefinitions.OPTIONS.FILE));
+        } else if (hasMainArgument) {
+            filepath = cleanFilePathArgument(optionParser.getMainArg());
+        } else if (openDefaultFile) {
+            try {
+                filepath = getDefaultPolicyFilePath();
+            } catch (URISyntaxException e) {
+                OutputController.getLogger().log(e);
+                throw new RuntimeException(e);
+            }
+        }
+        return filepath;
+    }
+
+    private static String cleanFilePathArgument(String filepath) {
+        if (filepath == null) {
+            return null;
+        } else if (filepath.isEmpty() || filepath.trim().isEmpty()) {
+            return null;
+        } else {
+            return filepath;
+        }
+    }
+
     /**
      * Create a new PolicyEditor instance without passing argv. The returned instance is not
      * yet set visible.
