@@ -47,8 +47,6 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.KeyEvent;
 import java.io.File;
-import java.io.FileOutputStream;
-import java.io.OutputStream;
 import java.io.PrintStream;
 import java.security.KeyStore;
 import java.security.cert.Certificate;
@@ -108,7 +106,7 @@ public class CertificatePane extends JPanel {
     JTabbedPane tabbedPane;
     private final JTable userTable;
     private final JTable systemTable;
-    private JComboBox certificateTypeCombo;
+    private JComboBox<CertificateType> certificateTypeCombo;
     private KeyStores.Type currentKeyStoreType;
     private KeyStores.Level currentKeyStoreLevel;
 
@@ -130,7 +128,7 @@ public class CertificatePane extends JPanel {
 
         userTable = new JTable(null);
         systemTable = new JTable(null);
-        disableForSystem = new ArrayList<JComponent>();
+        disableForSystem = new ArrayList<>();
 
         addComponents();
 
@@ -165,7 +163,7 @@ public class CertificatePane extends JPanel {
 
         JLabel certificateTypeLabel = new JLabel(R("CVCertificateType"));
 
-        certificateTypeCombo = new JComboBox(certificateTypes);
+        certificateTypeCombo = new JComboBox<>(certificateTypes);
         certificateTypeCombo.addActionListener(new CertificateTypeListener());
 
         certificateTypePanel.add(certificateTypeLabel, BorderLayout.LINE_START);
@@ -257,7 +255,7 @@ public class CertificatePane extends JPanel {
     private void readKeyStore() {
 
         Enumeration<String> aliases = null;
-        certs = new ArrayList<X509Certificate>();
+        certs = new ArrayList<>();
         try {
 
             //Get all of the X509Certificates and put them into an ArrayList
@@ -279,7 +277,7 @@ public class CertificatePane extends JPanel {
                                         SecurityUtil.getCN(c.getIssuerX500Principal().getName());
             }
         } catch (Exception e) {
-            //TODO
+            // TODO handle exception
            OutputController.getLogger().log(OutputController.Level.ERROR_ALL, e);
         }
     }
@@ -314,9 +312,7 @@ public class CertificatePane extends JPanel {
         if (result == JOptionPane.OK_OPTION) {
             return jpf.getPassword();
         }
-        else {
-            return null;
-        }
+        return null;
     }
 
     /** Allows storing KeyStores.Types in a JComponent */
@@ -342,7 +338,7 @@ public class CertificatePane extends JPanel {
         @Override
         @SuppressWarnings("unchecked")//this is just certificateTypeCombo, nothing else
         public void actionPerformed(ActionEvent e) {
-            JComboBox source = (JComboBox) e.getSource();
+            JComboBox<CertificateType> source = (JComboBox<CertificateType>) e.getSource();
             CertificateType type = (CertificateType) source.getSelectedItem();
             currentKeyStoreType = type.getType();
             repopulateTables();
@@ -396,18 +392,13 @@ public class CertificatePane extends JPanel {
                     } else {
                         CertificateUtils.addToKeyStore(chooser.getSelectedFile(), ks);
                     }
-                    File keyStoreFile = new File(KeyStores
-                                        .getKeyStoreLocation(currentKeyStoreLevel, currentKeyStoreType));
+                    File keyStoreFile = KeyStores.getKeyStoreLocation(currentKeyStoreLevel, currentKeyStoreType).getFile();
                     if (!keyStoreFile.isFile()) {
                         FileUtils.createRestrictedFile(keyStoreFile, true);
                     }
 
-                    OutputStream os = new FileOutputStream(keyStoreFile);
-                    try {
-                        ks.store(os, KeyStores.getPassword());
-                    } finally {
-                        os.close();
-                    }
+                    SecurityUtil.storeKeyStore(ks, keyStoreFile);
+
                     repopulateTables();
                 } catch (Exception ex) {
                     // TODO: handle exception
@@ -487,14 +478,11 @@ public class CertificatePane extends JPanel {
                                                         JOptionPane.YES_NO_OPTION);
                         if (i == 0) {
                             keyStore.deleteEntry(alias);
-                            File keyStoreFile = new File(KeyStores
-                                                        .getKeyStoreLocation(currentKeyStoreLevel, currentKeyStoreType));
+                            File keyStoreFile = KeyStores.getKeyStoreLocation(currentKeyStoreLevel, currentKeyStoreType).getFile();
                             if (!keyStoreFile.isFile()) {
                                 FileUtils.createRestrictedFile(keyStoreFile, true);
                             }
-                            FileOutputStream fos = new FileOutputStream(keyStoreFile);
-                            keyStore.store(fos, KeyStores.getPassword());
-                            fos.close();
+                            SecurityUtil.storeKeyStore(keyStore, keyStoreFile);
                         }
                     }
                     repopulateTables();
