@@ -65,6 +65,9 @@ public class StreamUtils {
 
     /**
      * Copy an input stream's contents into an output stream.
+     * @param input input stream
+     * @param output stream where to copy input
+     * @throws java.io.IOException if IO fails
      */
     public static void copyStream(InputStream input, OutputStream output)
             throws IOException {
@@ -82,9 +85,16 @@ public class StreamUtils {
         return readStreamAsString(stream, false);
     }
     
-    public static String readStreamAsString(InputStream stream, boolean includeEndOfLines)
-            throws IOException {
-        InputStreamReader is = new InputStreamReader(stream);
+    public static String readStreamAsString(InputStream stream, String encoding)  throws IOException {
+        return readStreamAsString(stream, false, encoding);
+    }
+    
+    public static String readStreamAsString(InputStream stream, boolean includeEndOfLines) throws IOException {
+        return readStreamAsString(stream, includeEndOfLines, "UTF-8");
+    }
+            
+    public static String readStreamAsString(InputStream stream, boolean includeEndOfLines, String encoding) throws IOException {
+        InputStreamReader is = new InputStreamReader(stream, encoding);
         StringBuilder sb = new StringBuilder();
         BufferedReader br = new BufferedReader(is);
         while (true) {
