@@ -40,6 +40,7 @@ import java.util.Map.Entry;
 
 import net.sourceforge.jnlp.IconDesc;
 import net.sourceforge.jnlp.JNLPFile;
+import net.sourceforge.jnlp.OptionsDefinitions;
 import net.sourceforge.jnlp.PluginBridge;
 import net.sourceforge.jnlp.StreamEater;
 import net.sourceforge.jnlp.cache.CacheUtil;
@@ -147,13 +148,17 @@ public class XDesktopEntry {
 
         }
         if (file.getInformation().getVendor() != null) {
-            fileContents += "Vendor=" + sanitize(file.getInformation().getVendor()) + "\n";
+            fileContents += "X-Vendor=" + sanitize(file.getInformation().getVendor()) + "\n";
         }
 
         if (JNLPRuntime.isWebstartApplication()) {
+            String htmlSwitch = "";
+            if (JNLPRuntime.isHtml()){
+                htmlSwitch = " "+OptionsDefinitions.OPTIONS.HTML.option;
+            }
             fileContents += "Exec="
-                    + getJavaWsBin() + " \"" + file.getSourceLocation() + "\"\n";
-            OutputController.getLogger().log("Using " + getJavaWsBin() + " as binary for " + file.getSourceLocation());
+                    + getJavaWsBin() + htmlSwitch + " \"" + file.getSourceLocation() + "\"\n";
+            OutputController.getLogger().log("Using " + getJavaWsBin()  + htmlSwitch + " as binary for " + file.getSourceLocation());
         } else {
             if (info.getShortcutType() == AccessWarningPaneComplexReturn.ShortcutResult.Shortcut.BROWSER) {
                 String browser = info.getBrowser();
@@ -266,7 +271,7 @@ public class XDesktopEntry {
 
     public File getShortcutTmpFile() {
         String userTmp = PathsAndFiles.TMP_DIR.getFullPath();
-        File shortcutFile = new File(userTmp + File.separator + FileUtils.sanitizeFileName(file.getTitle()) + ".desktop");
+        File shortcutFile = new File(userTmp + File.separator + getDesktopIconFileName());
         return shortcutFile;
     }
 
@@ -497,11 +502,15 @@ public class XDesktopEntry {
     }
 
     public File getLinuxDesktopIconFile() {
-        return new File(findFreedesktopOrgDesktopPathCatch() + "/" + getDesktopIconName() + ".desktop");
+        return new File(findFreedesktopOrgDesktopPathCatch() + "/" + getDesktopIconFileName());
     }
 
     public File getLinuxMenuIconFile() {
-        return new File(findAndVerifyJavawsMenuDir() + "/" + getDesktopIconName() + ".desktop");
+        return new File(findAndVerifyJavawsMenuDir() + "/" + getDesktopIconFileName());
+    }
+    
+    private String getDesktopIconFileName() {
+        return getDesktopIconName() + ".desktop";
     }
 
     private static String findAndVerifyGeneratedJnlpDir() {
@@ -522,7 +531,7 @@ public class XDesktopEntry {
         return fPath;
     }
 
-    private static String findFreedesktopOrgDesktopPathCatch() {
+    public static String findFreedesktopOrgDesktopPathCatch() {
         try {
             return findFreedesktopOrgDesktopPath();
         } catch (Exception ex) {
