@@ -30,16 +30,22 @@
 
 package net.sourceforge.nanoxml;
 
-import java.io.*;
-import java.util.*;
 
-import net.sourceforge.jnlp.runtime.JNLPRuntime;
+import java.io.IOException;
+import java.io.OutputStream;
+import java.io.PrintStream;
+import java.io.Reader;
+import java.util.Enumeration;
+import java.util.HashMap;
+import java.util.Map;
+import java.util.Set;
+import java.util.Vector;
 import net.sourceforge.jnlp.util.logging.OutputController;
 
 /**
  * XMLElement is a representation of an XML object. The object is able to parse
  * XML code.
- * <p><dl>
+ * <dl>
  * <dt><b>Parsing XML Data</b></dt>
  * <dd>
  * You can parse XML data using the following code:
@@ -84,7 +90,6 @@ import net.sourceforge.jnlp.util.logging.OutputController;
  * which has to return a new copy of the receiver.
  * </dd></dl>
  *
- *
  * @see net.sourceforge.nanoxml.XMLParseException
  *
  * @author Marc De Scheemaecker
@@ -102,7 +107,7 @@ public class XMLElement {
      *     <li>The keys and the values are strings.</li>
      * </ul></dd></dl>
      */
-    private Hashtable<String, Object> attributes;
+    private Map<String, Object> attributes;
 
     /**
      * Child elements of the element.
@@ -154,7 +159,7 @@ public class XMLElement {
      *     <li>The values are char arrays</li>
      * </ul></dd></dl>
      */
-    private Hashtable<String, char[]> entities;
+    private Map<String, char[]> entities;
 
     /**
      * The line number where the element starts.
@@ -178,7 +183,8 @@ public class XMLElement {
     private boolean ignoreWhitespace;
 
     /**
-     * Character read too much.<br>
+     * Character read too much.
+     * <p>
      * This character provides push-back functionality to the input reader
      * without having to use a PushbackReader.
      * If there is no such character, this field is {@code '\0'}.
@@ -189,6 +195,11 @@ public class XMLElement {
      * Character read too much for the comment remover.
      */
     private char sanitizeCharReadTooMuch;
+    
+   /**
+     * Whether the BOM header appeared
+     */
+    private boolean BOM = false;
 
     /**
      * The reader provided by the caller of the parse method.
@@ -210,9 +221,10 @@ public class XMLElement {
     private int parserLineNr;
 
     /**
-     * Creates and initializes a new XML element.<br>
+     * Creates and initializes a new XML element.
+     * <p>
      * Calling the construction is equivalent to:
-     * <ul><li>{@code new XMLElement(new Hashtable(), false, true)}</li></ul>
+     * <ul><li>{@code new XMLElement(new HashMap(), false, true)}</li></ul>
      *
      * <dl><dt><b>Postconditions:</b></dt><dd>
      * <ul><li>{@linkplain #countChildren} =&gt; 0</li>
@@ -225,7 +237,7 @@ public class XMLElement {
      * </ul></dd></dl>
      */
     public XMLElement() {
-        this(new Hashtable<String, char[]>(), false, true, true);
+        this(new HashMap<String, char[]>(), false, true, true);
     }
 
     /**
@@ -264,7 +276,7 @@ public class XMLElement {
      *     <li>{@linkplain #getName} =&gt; null</li>
      * </ul></dd></dl>
      */
-    protected XMLElement(Hashtable<String, char[]> entities,
+    protected XMLElement(Map<String, char[]> entities,
                          boolean skipLeadingWhitespace,
                          boolean fillBasicConversionTable,
                          boolean ignoreCase) {
@@ -272,13 +284,12 @@ public class XMLElement {
         this.ignoreCase = ignoreCase;
         this.name = null;
         this.contents = "";
-        this.attributes = new Hashtable<String, Object>();
-        this.children = new Vector<XMLElement>();
+        this.attributes = new HashMap<>();
+        this.children = new Vector<>();
         this.entities = entities;
         this.lineNr = 0;
-        Enumeration<String> e = this.entities.keys();
-        while (e.hasMoreElements()) {
-            String key = e.nextElement();
+        Set<String> e = this.entities.keySet();
+        for(String key: e) {
             Object value = this.entities.get(key);
             if (value instanceof String) {
                 entities.put(key, ((String) value).toCharArray());
@@ -347,7 +358,7 @@ public class XMLElement {
     }
 
     /**
-     * Returns the number of child elements of the element.
+     * @return the number of child elements of the element.
      *
      * <dl><dt><b>Postconditions:</b></dt><dd>
      * <ul><li>{@code result >= 0}</li>
@@ -358,18 +369,18 @@ public class XMLElement {
     }
 
     /**
-     * Enumerates the attribute names.
+     * @return Enumeration of the attribute names.
      *
      * <dl><dt><b>Postconditions:</b></dt><dd>
      * <ul><li>{@code result != null}</li>
      * </ul></dd></dl>
      */
     public Enumeration<String> enumerateAttributeNames() {
-        return this.attributes.keys();
+        return new Vector(this.attributes.keySet()).elements();
     }
 
     /**
-     * Enumerates the child elements.
+     * @return Enumeration the child elements.
      *
      * <dl><dt><b>Postconditions:</b></dt><dd>
      * <ul><li>{@code result != null}</li>
@@ -380,7 +391,7 @@ public class XMLElement {
     }
 
     /**
-     * Returns the PCDATA content of the object. If there is no such content,
+     * @return the PCDATA content of the object. If there is no such content,
      * {@code null} is returned.
      */
     public String getContent() {
@@ -388,7 +399,7 @@ public class XMLElement {
     }
 
     /**
-     * Returns the line nr in the source data on which the element is found.
+     * @return the line nr in the source data on which the element is found.
      * This method returns {@code 0} there is no associated source data.
      *
      * <dl><dt><b>Postconditions:</b></dt><dd>
@@ -400,7 +411,8 @@ public class XMLElement {
     }
 
     /**
-     * Returns an attribute of the element.<br>
+     * @return an attribute of the element.
+     * <p>
      * If the attribute doesn't exist, {@code null} is returned.
      *
      * @param name The name of the attribute.
@@ -487,7 +499,7 @@ public class XMLElement {
         this.parserLineNr = startingLineNr;
 
         for (;;) {
-            char ch = this.scanWhitespace();
+            char ch = this.scanLeadingWhitespace();
 
             if (ch != '<') {
                 throw this.expectedInput("<", ch);
@@ -510,6 +522,7 @@ public class XMLElement {
      * <p>
      * You should override this method when subclassing XMLElement.
      * </p>
+     * @return next element in tree based on global settings
      */
     protected XMLElement createAnotherElement() {
         return new XMLElement(this.entities,
@@ -560,6 +573,7 @@ public class XMLElement {
      * <ul><li>The next character read from the reader won't be an identifier
      *         character.</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected void scanIdentifier(StringBuffer result)
             throws IOException {
@@ -575,63 +589,95 @@ public class XMLElement {
         }
     }
 
+    private boolean isRegularWhiteSpace(char ch) {
+        switch (ch) {
+            case ' ':
+            case '\t':
+            case '\n':
+            case '\r':
+                return true;
+            default:
+                return false;
+        }
+    }
+    
     /**
      * This method scans an identifier from the current reader.
      *
      * @return the next character following the whitespace.
+     * @throws java.io.IOException if something goes wrong
      */
-    protected char scanWhitespace()
+    private char scanWhitespace()
             throws IOException {
-        for (;;) {
+        while(true) {
             char ch = this.readChar();
-            switch (ch) {
-                case ' ':
-                case '\t':
-                case '\n':
-                case '\r':
-                    break;
-                default:
-                    return ch;
+            if (!isRegularWhiteSpace(ch)) {
+                return ch;
+            }
+        }
+    }
+     /**
+     * This method scans an leading identifier from the current reader.
+     * 
+     * UNlike scanWhitespace, it skipps also BOM
+     *
+     * @return the next character following the whitespace.
+     * @throws java.io.IOException if something goes wrong
+     */
+    private char scanLeadingWhitespace()
+            throws IOException {
+        while(true) {
+            char ch = this.readChar();
+            //this is BOM , not space
+            if (ch == '﻿') {
+                BOM = true;
+            } else if (!isRegularWhiteSpace(ch)) {
+                return ch;
             }
         }
     }
 
     /**
-     * This method scans an identifier from the current reader.<br>
+     * This method scans an identifier from the current reader.
+     * <p>
      * The scanned whitespace is appended to {@code result}.
      *
+     * @param result where to append scanned text
      * @return the next character following the whitespace.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code result != null}</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected char scanWhitespace(StringBuffer result)
             throws IOException {
-        for (;;) {
+        while (true) {
             char ch = this.readChar();
-            switch (ch) {
-                case ' ':
-                case '\t':
-                case '\n':
-                    result.append(ch);
-                    break;
-                case '\r':
-                    break;
-                default:
-                    return ch;
+            if (!isRegularWhiteSpace(ch)) {
+                return ch;
+            } else {
+                switch (ch) {
+                    case ' ':
+                    case '\t':
+                    case '\n':
+                        result.append(ch);
+                }
             }
         }
     }
 
     /**
-     * This method scans a delimited string from the current reader.<br>
+     * This method scans a delimited string from the current reader.
+     * <p>
      * The scanned string without delimiters is appended to {@code string}.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code string != null}</li>
      *     <li>the next char read is the string delimiter</li>
      * </ul></dd></dl>
+     * @param string where to append the result
+     * @throws java.io.IOException if something goes wrong
      */
     protected void scanString(StringBuffer string)
             throws IOException {
@@ -653,13 +699,17 @@ public class XMLElement {
 
     /**
      * Scans a {@code #PCDATA} element. CDATA sections and entities are
-     * resolved.<br>
-     * The next &lt; char is skipped.<br>
+     * resolved.
+     * <p>
+     * The next &lt; char is skipped.
+     * <p>
      * The scanned data is appended to {@code data}.
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code data != null}</li>
      * </ul></dd></dl>
+     * @param data where to append data
+     * @throws java.io.IOException if something goes wrong
      */
     protected void scanPCData(StringBuffer data)
             throws IOException {
@@ -689,6 +739,9 @@ public class XMLElement {
      * <ul><li>{@code buf != null}</li>
      *     <li>The first &lt; has already been read.</li>
      * </ul></dd></dl>
+     * @param buf buffer where to append data
+     * @return whether the CDATA were ok
+     * @throws java.io.IOException if something goes wrong
      */
     protected boolean checkCDATA(StringBuffer buf)
             throws IOException {
@@ -743,6 +796,7 @@ public class XMLElement {
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>The first &lt;!-- has already been read.</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected void skipComment()
             throws IOException {
@@ -784,6 +838,7 @@ public class XMLElement {
      * <ul><li>The first &lt;! has already been read.</li>
      *     <li>{@code bracketLevel &gt;= 0}</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected void skipSpecialTag(int bracketLevel)
             throws IOException {
@@ -831,7 +886,8 @@ public class XMLElement {
     }
 
     /**
-     * Scans the data for literal text.<br>
+     * Scans the data for literal text.
+     * <p>
      * Scanning stops when a character does not match or after the complete
      * text has been checked, whichever comes first.
      *
@@ -840,6 +896,8 @@ public class XMLElement {
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code literal != null}</li>
      * </ul></dd></dl>
+     * @return true if literal was ok
+     * @throws java.io.IOException  if something goes wrong
      */
     protected boolean checkLiteral(String literal)
             throws IOException {
@@ -854,6 +912,8 @@ public class XMLElement {
 
     /**
      * Reads a character from a reader.
+     * @return the read char
+     * @throws java.io.IOException if something goes wrong
      */
     protected char readChar()
             throws IOException {
@@ -883,13 +943,14 @@ public class XMLElement {
      * <ul><li>The first &lt; has already been read.</li>
      *     <li>{@code elt != null}</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected void scanElement(XMLElement elt)
             throws IOException {
         StringBuffer buf = new StringBuffer();
         this.scanIdentifier(buf);
-        String name = buf.toString();
-        elt.setName(name);
+        String lname = buf.toString();
+        elt.setName(lname);
         char ch = this.scanWhitespace();
         while ((ch != '>') && (ch != '/')) {
             buf.setLength(0);
@@ -976,8 +1037,8 @@ public class XMLElement {
             throw this.expectedInput("/");
         }
         this.unreadChar(this.scanWhitespace());
-        if (!this.checkLiteral(name)) {
-            throw this.expectedInput(name);
+        if (!this.checkLiteral(lname)) {
+            throw this.expectedInput(lname);
         }
         if (this.scanWhitespace() != '>') {
             throw this.expectedInput(">");
@@ -985,7 +1046,8 @@ public class XMLElement {
     }
 
     /**
-     * Resolves an entity. The name of the entity is read from the reader.<br>
+     * Resolves an entity. The name of the entity is read from the reader.
+     * <p>
      * The value of the entity is appended to {@code buf}.
      *
      * @param buf Where to put the entity value.
@@ -994,6 +1056,7 @@ public class XMLElement {
      * <ul><li>The first &amp; has already been read.</li>
      *     <li>{@code buf != null}</li>
      * </ul></dd></dl>
+     * @throws java.io.IOException if something goes wrong
      */
     protected void resolveEntity(StringBuffer buf)
             throws IOException {
@@ -1050,6 +1113,7 @@ public class XMLElement {
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code name != null}</li>
      * </ul></dd></dl>
+     * @return exception to be thrown
      */
     protected XMLParseException invalidValueSet(String name) {
         String msg = "Invalid value set (entity name = \"" + name + "\")";
@@ -1067,6 +1131,7 @@ public class XMLElement {
      * <ul><li>{@code name != null}</li>
      *     <li>{@code value != null}</li>
      * </ul></dd></dl>
+     * @return exception to be used
      */
     protected XMLParseException invalidValue(String name,
                                              String value) {
@@ -1078,6 +1143,7 @@ public class XMLElement {
     /**
      * Creates a parse exception for when the end of the data input has been
      * reached.
+     * @return  exception to be used
      */
     protected XMLParseException unexpectedEndOfData() {
         String msg = "Unexpected end of data reached";
@@ -1093,6 +1159,7 @@ public class XMLElement {
      * <ul><li>{@code context != null}</li>
      *     <li>{@code context.length() &gt; 0}</li>
      * </ul></dd></dl>
+     * @return exception to be used
      */
     protected XMLParseException syntaxError(String context) {
         String msg = "Syntax error while parsing " + context;
@@ -1110,6 +1177,7 @@ public class XMLElement {
      * <ul><li>{@code charSet != null}</li>
      *     <li>{@code charSet.length() &gt; 0}</li>
      * </ul></dd></dl>
+     * @return exception to be used
      */
     protected XMLParseException expectedInput(String charSet) {
         String msg = "Expected: " + charSet;
@@ -1127,6 +1195,7 @@ public class XMLElement {
      * <ul><li>{@code charSet != null}</li>
      *     <li>{@code charSet.length() &gt; 0}</li>
      * </ul></dd></dl>
+     * @return exception to be used
      */
     protected XMLParseException expectedInput(String charSet, char ch) {
         String msg = "Expected: '" + charSet + "'" + " but got: '" + ch + "'";
@@ -1137,6 +1206,7 @@ public class XMLElement {
      * Creates a parse exception for when an entity could not be resolved.
      *
      * @param name The name of the entity.
+     * @return exception to be used
      *
      * <dl><dt><b>Preconditions:</b></dt><dd>
      * <ul><li>{@code name != null}</li>
@@ -1152,14 +1222,13 @@ public class XMLElement {
      * Reads an xml file and removes the comments, leaving only relevant
      * xml code.
      *
-     * @param isr The reader of the {@link InputStream} containing the xml.
-     * @param pout The {@link PipedOutputStream} that will be receiving the
+     * @param isr The reader of the {@link java.io.InputStream} containing the xml.
+     * @param pout The {@link java.io.PipedOutputStream} that will be receiving the
      *             filtered xml file.
      */
     public void sanitizeInput(Reader isr, OutputStream pout) {
         StringBuilder line = new StringBuilder();
-        try {
-            PrintStream out = new PrintStream(pout);
+        try (PrintStream out = new PrintStream(pout)) {
             this.sanitizeCharReadTooMuch = '\0';
             this.reader = isr;
             this.parserLineNr = 0;
@@ -1247,7 +1316,6 @@ public class XMLElement {
                 }
                 prev = next;
             }
-            out.close();
             isr.close();
         } catch (Exception e) {
             // Print the stack trace here -- xml.parseFromReader() will
@@ -1259,4 +1327,11 @@ public class XMLElement {
 
         }
     }
+
+    public boolean isBOM() {
+        return BOM;
+    }
+    
+    
+    
 }
