@@ -37,6 +37,7 @@ exception statement from your version.
 package net.sourceforge.jnlp.security.policyeditor;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotEquals;
 import static org.junit.Assert.assertTrue;
 
 import org.junit.Test;
@@ -116,14 +117,31 @@ public class CustomPermissionTest {
     }
 
     @Test
-    public void testToStringWithoutActions() throws Exception {
+    public void testToStringWithNoActions() throws Exception {
+        final CustomPermission cp = new CustomPermission("java.lang.RuntimePermission", "createClassLoader");
+        final String expected = "permission java.lang.RuntimePermission \"createClassLoader\";";
+        assertEquals(expected, cp.toString());
+    }
+
+    @Test
+    public void testToStringWithEmptyActions() throws Exception {
         final CustomPermission cp = new CustomPermission("java.lang.RuntimePermission", "createClassLoader", "");
         final String expected = "permission java.lang.RuntimePermission \"createClassLoader\";";
         assertEquals(expected, cp.toString());
     }
 
     @Test
-    public void testCompareTo() throws Exception {
+    public void testCompareToWithNoActions() throws Exception {
+        final CustomPermission cp1 = new CustomPermission("java.io.FilePermission", "*", "read");
+        final CustomPermission cp2 = new CustomPermission("java.io.FilePermission", "${user.home}${/}*", "read");
+        final CustomPermission cp3 = new CustomPermission("java.lang.RuntimePermission", "queuePrintJob");
+        assertTrue("cp1.compareTo(cp2) should be > 0", cp1.compareTo(cp2) > 0);
+        assertTrue("cp1.compareTo(cp1) should be 0", cp1.compareTo(cp1) == 0);
+        assertTrue("cp2.compareTo(cp3) should be < 0", cp2.compareTo(cp3) < 0);
+    }
+
+    @Test
+    public void testCompareToWithEmptyActions() throws Exception {
         final CustomPermission cp1 = new CustomPermission("java.io.FilePermission", "*", "read");
         final CustomPermission cp2 = new CustomPermission("java.io.FilePermission", "${user.home}${/}*", "read");
         final CustomPermission cp3 = new CustomPermission("java.lang.RuntimePermission", "queuePrintJob", "");
@@ -131,4 +149,29 @@ public class CustomPermissionTest {
         assertTrue("cp1.compareTo(cp1) should be 0", cp1.compareTo(cp1) == 0);
         assertTrue("cp2.compareTo(cp3) should be < 0", cp2.compareTo(cp3) < 0);
     }
+
+    @Test
+    public void testConstructFromEnumsToString() throws Exception {
+        final CustomPermission cp = new CustomPermission(PermissionType.FILE_PERMISSION, PermissionTarget.USER_HOME, PermissionActions.READ);
+        final String permissionString = "permission java.io.FilePermission \"${user.home}\", \"read\";";
+        assertEquals(permissionString, cp.toString());
+    }
+
+    @Test
+    public void testEquals() throws Exception {
+        final CustomPermission cp1 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.CLASSLOADER);
+        final CustomPermission cp2 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.CLASSLOADER);
+        final CustomPermission cp3 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.ACCESS_THREADS);
+        assertEquals(cp1, cp2);
+        assertNotEquals(cp1, cp3);
+    }
+
+    @Test
+    public void testHashcode() throws Exception {
+        final CustomPermission cp1 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.CLASSLOADER);
+        final CustomPermission cp2 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.CLASSLOADER);
+        final CustomPermission cp3 = new CustomPermission(PermissionType.RUNTIME_PERMISSION, PermissionTarget.ACCESS_THREADS);
+        assertEquals(cp1.hashCode(), cp2.hashCode());
+        assertNotEquals(cp1.hashCode(), cp3.hashCode());
+    }
 }
