@@ -77,11 +77,6 @@ public class Firefox extends MozillaFamilyLinuxBrowser {
 
     @Override
     public void beforeKill(String s) {
-        try {
-            ProcessAssasin.closeWindows(s);
-        } catch (Exception ex) {
-            throw new RuntimeException(ex);
-        }
     }
 
     @Override
